@@ -14,7 +14,7 @@ from mio import cli
 
 import yaml
 from yaml.loader import SafeLoader
-from alive_progress import alive_bar
+from tqdm import tqdm
 from multiprocessing import Process
 import threading
 from threading import BoundedSemaphore
@@ -52,7 +52,7 @@ class TestSuite:
         self.max_jobs          = []
         if simulator == "viv":
             self.simulator = common.simulators_enum.VIVADO
-        elif simulator == "mtr":
+        elif simulator == "mdc":
             self.simulator = common.simulators_enum.METRICS
         elif simulator == "vcs":
             self.simulator = common.simulators_enum.VCS
@@ -301,6 +301,7 @@ class TestSuite:
         sim_job.is_regression   = True
         sim_job.regression_name = cfg.regression_name
         sim_job.regression_timestamp = self.timestamp
+        sim_job.one_shot  = False
         sim_job.compile   = True
         sim_job.elaborate = False
         sim_job.simulate  = False
@@ -322,6 +323,7 @@ class TestSuite:
         sim_job.is_regression   = True
         sim_job.regression_name = cfg.regression_name
         sim_job.regression_timestamp = self.timestamp
+        sim_job.one_shot  = False
         sim_job.compile   = False
         sim_job.elaborate = True
         sim_job.simulate  = False
@@ -523,7 +525,8 @@ def launch_sim_jobs(ip, test_suite, regression, sim_job_list, dry_mode):
     common.create_dir(cfg.regr_results_dir + "/" + cfg.target_ip_name + "_" + regression_name + "/" + test_suite.timestamp)
     sem = BoundedSemaphore(regression.max_jobs)
     sem_cfg = BoundedSemaphore(1)
-    with alive_bar(len(sim_job_list), bar = 'smooth') as bar:
+    with tqdm(sim_job_list) as bar:
+    #with alive_bar(len(sim_job_list), bar = 'smooth') as bar:
         for sim_job in sim_job_list:
             common.dbg("Launching test threads")
             thread = Thread(target=launch_test, args=(ip,test_suite,sim_job,dry_mode,))
@@ -580,7 +583,7 @@ def launch_test(ip, test_suite, sim_job, dry_mode):
     else:
         eal.simulate(ip, sim_job)
     common.dbg("Done simulating:\n" + str(sim_job))
-    bar()
+    bar.update(1)
     done_with_turn()
 
 
