@@ -21,7 +21,7 @@ from base64 import b64encode
 import os
 import sys
 import shutil
-from alive_progress import alive_bar
+from tqdm import tqdm
 
 
 base_url      = "https://mooreio.com"
